@@ -1,31 +1,16 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2014-2017 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2014-2018 Richard Hughes <richard@hughsie.com>
  *
- * Licensed under the GNU Lesser General Public License Version 2.1
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
+ * SPDX-License-Identifier: LGPL-2.1+
  */
 
-#if !defined (__APPSTREAM_GLIB_H) && !defined (AS_COMPILATION)
+#pragma once
+
+#if !defined (__APPSTREAM_GLIB_H_INSIDE__) && !defined (AS_COMPILATION)
 #error "Only <appstream-glib.h> can be included directly."
 #endif
 
-#ifndef __AS_APP_H
-#define __AS_APP_H
-
 #include <glib-object.h>
 
 #include "as-bundle.h"
@@ -40,6 +25,7 @@
 #include "as-review.h"
 #include "as-suggest.h"
 #include "as-content-rating.h"
+#include "as-agreement.h"
 #include "as-translation.h"
 
 G_BEGIN_DECLS
@@ -108,6 +94,7 @@ typedef enum {
  * @AS_APP_SUBSUME_FLAG_SCREENSHOTS:	Copy the screenshots
  * @AS_APP_SUBSUME_FLAG_REVIEWS:	Copy the reviews
  * @AS_APP_SUBSUME_FLAG_CONTENT_RATINGS: Copy the content ratings
+ * @AS_APP_SUBSUME_FLAG_AGREEMENTS:	Copy the agreements
  * @AS_APP_SUBSUME_FLAG_PROVIDES:	Copy the provides
  * @AS_APP_SUBSUME_FLAG_ICONS:		Copy the icons
  * @AS_APP_SUBSUME_FLAG_MIMETYPES:	Copy the mimetypes
@@ -170,6 +157,7 @@ typedef enum {
 	AS_APP_SUBSUME_FLAG_SOURCE_KIND		= 1ull << 34,	/* Since: 0.6.1 */
 	AS_APP_SUBSUME_FLAG_SUGGESTS		= 1ull << 35,	/* Since: 0.6.3 */
 	AS_APP_SUBSUME_FLAG_LAUNCHABLES		= 1ull << 36,	/* Since: 0.6.13 */
+	AS_APP_SUBSUME_FLAG_AGREEMENTS		= 1ull << 37,	/* Since: 0.7.8 */
 	/*< private >*/
 	AS_APP_SUBSUME_FLAG_LAST,
 } AsAppSubsumeFlags;
@@ -182,6 +170,7 @@ typedef enum {
 					 AS_APP_SUBSUME_FLAG_COMMENT | \
 					 AS_APP_SUBSUME_FLAG_COMPULSORY | \
 					 AS_APP_SUBSUME_FLAG_CONTENT_RATINGS | \
+					 AS_APP_SUBSUME_FLAG_AGREEMENTS | \
 					 AS_APP_SUBSUME_FLAG_DESCRIPTION | \
 					 AS_APP_SUBSUME_FLAG_DEVELOPER_NAME | \
 					 AS_APP_SUBSUME_FLAG_EXTENDS | \
@@ -309,6 +298,7 @@ typedef AsFormatKind AsAppSourceKind;
  * @AS_APP_KIND_LOCALIZATION:		Localization data
  * @AS_APP_KIND_CONSOLE:		Console program
  * @AS_APP_KIND_DRIVER:			Driver for hardware support
+ * @AS_APP_KIND_ICON_THEME:		An icon theme
  *
  * The component type.
  **/
@@ -330,6 +320,7 @@ typedef enum {
 	AS_APP_KIND_LOCALIZATION,	/* Since: 0.5.11 */
 	AS_APP_KIND_CONSOLE,		/* Since: 0.6.1 */
 	AS_APP_KIND_DRIVER,		/* Since: 0.6.3 */
+	AS_APP_KIND_ICON_THEME,		/* Since: 0.7.17 */
 	/*< private >*/
 	AS_APP_KIND_LAST
 } AsAppKind;
@@ -348,6 +339,7 @@ typedef enum {
  * @AS_APP_QUIRK_NEEDS_USER_ACTION:	The component requires some kind of user action
  * @AS_APP_QUIRK_IS_PROXY:		Is a proxy app that operates on other applications
  * @AS_APP_QUIRK_REMOVABLE_HARDWARE:	The device is unusable whilst the action is performed
+ * @AS_APP_QUIRK_DEVELOPER_VERIFIED:	The app developer has been verified
  *
  * The component attributes.
  **/
@@ -364,6 +356,7 @@ typedef enum {
 	AS_APP_QUIRK_NEEDS_USER_ACTION	= 1 << 8,	/* Since: 0.6.2 */
 	AS_APP_QUIRK_IS_PROXY 		= 1 << 9,	/* Since: 0.6.6 */
 	AS_APP_QUIRK_REMOVABLE_HARDWARE	= 1 << 10,	/* Since: 0.6.6 */
+	AS_APP_QUIRK_DEVELOPER_VERIFIED	= 1 << 11,	/* Since: 0.7.11 */
 	/*< private >*/
 	AS_APP_QUIRK_LAST
 } AsAppQuirk;
@@ -646,6 +639,8 @@ void		 as_app_add_review		(AsApp		*app,
 						 AsReview	*review);
 void		 as_app_add_content_rating	(AsApp		*app,
 						 AsContentRating *content_rating);
+void		 as_app_add_agreement		(AsApp		*app,
+						 AsAgreement	*agreement);
 void		 as_app_add_icon		(AsApp		*app,
 						 AsIcon		*icon);
 void		 as_app_add_bundle		(AsApp		*app,
@@ -707,8 +702,13 @@ gboolean	 as_app_to_file			(AsApp		*app,
 						 GFile		*file,
 						 GCancellable	*cancellable,
 						 GError		**error);
+GString		*as_app_to_xml			(AsApp		*app,
+						 GError		**error);
 AsContentRating	*as_app_get_content_rating	(AsApp		*app,
 						 const gchar 	*kind);
+AsAgreement	*as_app_get_agreement_by_kind	(AsApp		*app,
+						 AsAgreementKind kind);
+AsAgreement	*as_app_get_agreement_default	(AsApp		*app);
 AsScreenshot	*as_app_get_screenshot_default	(AsApp		*app);
 AsIcon		*as_app_get_icon_default	(AsApp		*app);
 AsIcon		*as_app_get_icon_for_size	(AsApp		*app,
@@ -760,5 +760,3 @@ G_DEPRECATED_FOR(as_format_guess_kind);
 G_GNUC_END_IGNORE_DEPRECATIONS
 
 G_END_DECLS
-
-#endif /* __AS_APP_H */
